..  VencoPy publications file created on June 15, 2021
    by Fabia Miorelli
    Licensed under CC BY 4.0: https://creativecommons.org/licenses/by/4.0/deed.en

.. _publications:

Journal Publications and Conference Contributions
=======================================================

Journal Publications
---------------------------------------------------

An overview of the main publications using and applying venco.py as main tool is
available below:


- Miorelli et al. (2024), *An open-source python-based model to represent the
  charging flexibility and vehicle-to-grid potential of electric vehicles in
  energy systems models: venco.py*. Journal of Open Source Software (submitted).
- Wulff et al. (2021), *Vehicle Energy Consumption in Python (VencoPy):
  Presenting and Demonstrating an Open Source Tool to Calculate Electric Vehicle
  Charging Flexibility*. Energies, MDPI. 2021; 14(14):4349.
  https://doi.org/10.3390/en14144349 .
- Wulff et al. (2020), *Comparing Power-System and User-Oriented Battery
  Electric Vehicle Charging Representation and its Impact on Energy System
  Modeling*. Energies, MDPI. 2020; 13(5):1093.
  https://doi.org/10.3390/en13051093 .


Conference Contributions
---------------------------------------------------


An overview of conferences contributions including venco.py is listed below:

- Miorelli, F., Sasanpour, S., Gils, H.C., Jochem P.: "Stochastic expansion
  planning of the energy system under electric vehicle charging strategies and
  charging infrastructure deployment uncertainty", International
  Conference on Operations Research (OR), Munich, 03-06 September 2024
- Miorelli, F., Schmugge, J., Gils, H.C., Jochem P.: "The flexibility potential
  from smart charging of electric vehicles in Europe", 45th International
  Association for Energy Economics (IAEE) International Conference “Energy
  Sustainability, Security, Efficiency and Accessibility in a Time of
  Transition”, Istanbul, 24-27 June 2024
- Miorelli, F.: "Decarbonising transport and power: coupling both sectors
  through electrification", IEEE Vehicle Power and Propulsion (VPPC) conference
  2023, Milan, 24-27 October 2023
- Frey, U., Nitsch, F., Sperber, E., El Ghazi, A., Miorelli, F., Schimeczek, C.,
  Kaya, A., Rebennack, S.: "Forecasting multiple attributes considering
  uncertainties in a coupled energy systems model", 17th International
  Conference on Computational and Financial Econometrics (CFE) 2023, Berlin,
  16-18 December 2023
- Frey, U., Sperber, E., El Ghazi, A., Miorelli, F., Schimeczek, C., Stumpf, S.,
  Kaya, A., Rebennack, S.: "Modellierung von Akteursverhalten mit maschinellem
  Lernen in einem dezentralen Energiesystem", OR im Umweltschutz, Zurich, 25-26
  October 2023
- Frey, U., Sperber, E., El Ghazi, A., Miorelli, F., Schimeczek, C., Stumpf, S.,
  Kaya, A., Rebennack, S.: "Uncertainties in transition pathways towards Net
  Zero in a decentralized energy system", European Climate and Energy Modelling
  Forum (ECEMP) 2023, Online, 5-6 October 2023
- Frey, U., Sperber, E., El Ghazi, A. A., Miorelli, F., Schimeczek, C., Stumpf,
  S., Kaya, A., Rebennack, S.: "Uncertainties and interactions in various
  transition pathways of a decentralised energy system", 12th International Ruhr
  Energy Conference (INREC) 2023 "Uncertainties in Energy - Markets, Systems &
  Decisions", Essen, 5-6 September 2023
- Miorelli, F., Arellano Ruiz, E. S., Jochem P.: "Electric vehicle charging
  infrastructure in transportation research and energy systems analysis:
  Semantic interoperability of modelling approaches", World Conference on
  Transport Research (WCTR) 2023, Montréal, 17-21 July 2023
- Miorelli, F., Gils, H.C., Jochem P.: "Electric vehicle charging flexibility
  from representative mobility data: the example of two datasets for passenger
  and commercial transport in Germany", International EV Conference, Edinburgh,
  21-23 June 2023
- Miorelli, F., Gils, H.C., Jochem P.: "Investigating the economic granularity
  gap in the modelling of battery electric vehicles: An analysis from a
  power-system and a user-centric perspective", 44th International Association
  for Energy Economics (IAEE) International Conference "Pathways to a Clean,
  Stable and Sustainable Energy Future", Riyadh, 4-9 February 2023
- Wulff, N., Refa, N., Miorelli, F., Gils, H. C., Jochem, P.: "Qualification of
  charging pattern accuracy by a two-level validation approach for the case of
  Germany", 6th E-Mobility Power System Integration Symposium (EMPSIS), Den
  Haag, 10 October 2022
- Miorelli, F., Frey, U., Gils, H.C., Jochem P.: "Electric vehicles smart
  charging: Representative load profiles based on residential time-varying
  electricity tariffs and household characteristics", 17th International
  Association for Energy Economics (IAEE) European Energy Conference “The Future
  of Global Energy Systems”, Athens, 20-24 September 2022
- Wulff, N., Gils, H. C.: "Vehicle Energy Consumption in Python (VencoPy):
  Presenting and Demonstrating an Open Source Tool to Calculate Electric Vehicle
  Charging Flexibility", 6th Smart Energy Systems Conference (SES), Aalborg,
  05-06 October 2020
- Wulff, N.: "Vehicle Energy Consumption in Python and some insights from a
  recent publication process", Open Energy Modelling Workshop (Open-Mod),
  Berlin, 16 January 2020
- Wulff, N.: "Describing transport for energy system modelling: Input for an
  openmod do-a-thon", Open Energy Modelling Workshop (Open-Mod), Aarhus, 24 May
  2019
- Wulff, N., Steck, F., Hoyer-Klick, C., Anderson, J. E.: "Behaviour-driven
  battery electric vehicle charging decisions and its implications for the
  German power system", 16th International Association for Energy Economics
  (IAEE) European Energy Conference “Energy Challenges for the Next Decade”,
  Ljubljana, 26-28 August 2019


